<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// C
	'compresseur_description' => 'Gwaskadurez css ha javascript en titouroù ar pajennoù html deus <code>ecrire/</code> ha/pe deus al lec’h publik',
	'compresseur_slogan' => 'Gwaskadurezh css ha javascript',
];
